Changelog
=========


(unreleased)
------------
- Coverage badge. [Oliver]
- PyPI version badge. [Oliver]
- Getting on with the badges. [Oliver]
- Another try. [Oliver]
- Another README.rst trial. [Oliver]
- Change README.rst with travis build. [Oliver]
- Requires Travis. [Oliver]
- Introducing requires.io. [Oliver]
- Changed file structure, moved pdf2textbox directory out of src.
  [Oliver]
- Changed setup.py to make import with import src.pdf2textbox possible -
  could not be imported before. [Oliver]
- Improved testing coverage, now with cli option '-s' (i.e. --slice)
  [Oliver]
- Added tests for conversion of PDF files with and without header.
  [Oliver]
- Improved recognition of headers and columns. [Oliver]
- Added option to provide url or file location at the cli. [Oliver]
- Integrate check for number of columns, find header lines, layout, page
  numbers. [Oliver]
- Further checking out of pydf2. [Oliver]
- New file for pypdf2. [Oliver]
- Added test_content.py, seems rather awkward. [Oliver]
- Trying to resolve conflicts by deleting test_content.py. [Oliver]
- Trying to push up the PDF files. [Oliver]
- Merge branch 'master' of https://github.com/0LL13/pdf2textbox because
  otherwise it will not accept the changes I did in this cloned repo.
  [Oliver]
- Create LICENSE. [Oliver Stapel]
- Changed tox.ini. [Oliver]
- Changes from different machine. Most importantly checking content.
  [Oliver]
- Now pushing from the original repo. [Oliver]
- Previous change of setup.py did not work, try again. [Oliver]
- Changed to version 0.1.2 to avoid pypi's error message. [Oliver]
- Moved requirements.txt back to root. [Oliver]
- Changed .travis.yml before_install since PYTHONPATH did not work, now
  command python setup.py install in before_install. [Oliver]
- Quick fix before_install: export PYTHONPATH including pwd now.
  [Oliver]
- Changed python to 3.6 only. [Oliver]
- Back to zero: .travis.yml like they say in th docs. [Oliver]
- Moved requirements.txt back to src/pdf2textbox and changed
  .travis.yml. [Oliver]
- Moved requirements.txt to root. [Oliver]
- Version 0.1.1. [Oliver]
- Changing parameters to fit PEP8 - however the conversion to text is
  missing paragraphs, new approach necessary. [Oliver]
- Version 0.1. [Oliver]


0.1 (2018-04-11)
----------------
- Correcting github name. [Oliver]
- Removing bin, lib, and __pycache__, adding .gitignore. [Oliver]

